Index

A B C D E F G H I J L M N O P Q R S T U V W 
All Classes and Interfaces|All Packages|Serialized Form

A

AbstractCommand - Class in org.springframework.shell.core.command
Base class helping to build shell commands.
AbstractCommand(String, String) - Constructor for class org.springframework.shell.core.command.AbstractCommand
 
AbstractCommand(String, String, String) - Constructor for class org.springframework.shell.core.command.AbstractCommand
 
AbstractCommand(String, String, String, String) - Constructor for class org.springframework.shell.core.command.AbstractCommand
 
AbstractCommand(String, String, String, String, boolean) - Constructor for class org.springframework.shell.core.command.AbstractCommand
 
addArgument(CommandArgument) - Method in class org.springframework.shell.core.command.ParsedInput.Builder
 
addOption(CommandOption) - Method in class org.springframework.shell.core.command.ParsedInput.Builder
 
addSubCommand(String) - Method in class org.springframework.shell.core.command.ParsedInput.Builder
 
afterPropertiesSet() - Method in class org.springframework.shell.core.command.Version
 
afterSingletonsInstantiated() - Method in class org.springframework.shell.core.command.CommandRegistry
 
alias() - Element in annotation interface org.springframework.shell.core.command.annotation.Command
Define aliases as an array that can be defined as:
aliases(String...) - Method in class org.springframework.shell.core.command.Command.Builder
 
alwaysAvailable() - Static method in interface org.springframework.shell.core.command.availability.AvailabilityProvider
 
apply(CompletionContext) - Method in class org.springframework.shell.core.command.completion.CompositeCompletionProvider
 
apply(CompletionContext) - Method in class org.springframework.shell.core.command.completion.DefaultCompletionProvider
 
apply(CompletionContext) - Method in class org.springframework.shell.core.command.completion.EnumCompletionProvider
 
apply(CompletionContext) - Method in class org.springframework.shell.core.command.completion.FileNameCompletionProvider
 
Argument - Annotation Interface in org.springframework.shell.core.command.annotation
Annotation marking a method parameter as an argument to a Command.
arguments() - Method in record class org.springframework.shell.core.command.ParsedInput
Returns the value of the arguments record component.
arguments(CommandArgument...) - Method in class org.springframework.shell.core.command.Command.Builder
 
Arguments - Annotation Interface in org.springframework.shell.core.command.annotation
Annotation marking a method parameter as a target for a collection of arguments to a Command.
arity() - Element in annotation interface org.springframework.shell.core.command.annotation.Arguments
Define the maximum number of arguments to be collected.
artifact() - Method in record class org.springframework.shell.core.command.Version.BuildProperties
Returns the value of the artifact record component.
Availability - Record Class in org.springframework.shell.core.command.availability
Indicates whether a command is currently available or not.
Availability(String) - Constructor for record class org.springframework.shell.core.command.availability.Availability
Creates an instance of a Availability record class.
AVAILABILITY_ERROR - Static variable in record class org.springframework.shell.core.command.ExitStatus
 
availabilityProvider() - Element in annotation interface org.springframework.shell.core.command.annotation.Command
Define availability provider bean name.
availabilityProvider(AvailabilityProvider) - Method in class org.springframework.shell.core.command.Command.Builder
 
AvailabilityProvider - Interface in org.springframework.shell.core.command.availability
Interface resolving Availability.
available() - Static method in record class org.springframework.shell.core.command.availability.Availability
 

B

branch() - Method in record class org.springframework.shell.core.command.Version.GitProperties
Returns the value of the branch record component.
build() - Method in class org.springframework.shell.core.command.CommandArgument.Builder
 
build() - Method in class org.springframework.shell.core.command.CommandOption.Builder
 
build() - Method in class org.springframework.shell.core.command.ParsedInput.Builder
 
builder() - Static method in interface org.springframework.shell.core.command.Command
Creates and returns a new instance of a Builder for defining and constructing commands.
builder() - Static method in record class org.springframework.shell.core.command.ParsedInput
 
Builder() - Constructor for class org.springframework.shell.core.command.Command.Builder
 
Builder() - Constructor for class org.springframework.shell.core.command.CommandArgument.Builder
 
Builder() - Constructor for class org.springframework.shell.core.command.CommandOption.Builder
 
Builder() - Constructor for class org.springframework.shell.core.command.ParsedInput.Builder
 
BuildProperties(String, String, String, String, Instant) - Constructor for record class org.springframework.shell.core.command.Version.BuildProperties
Creates an instance of a BuildProperties record class.

C

category() - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
category(String) - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
Clear - Class in org.springframework.shell.core.command
ANSI console clear command.
Clear() - Constructor for class org.springframework.shell.core.command.Clear
 
clearCommands() - Method in class org.springframework.shell.core.command.CommandRegistry
 
close() - Method in class org.springframework.shell.core.FileInputProvider
 
code() - Method in record class org.springframework.shell.core.command.ExitStatus
Returns the value of the code record component.
Command - Interface in org.springframework.shell.core.command
 
Command - Annotation Interface in org.springframework.shell.core.command.annotation
Annotation marking a method to be a shell command.
Command.Builder - Class in org.springframework.shell.core.command
Builder for creating command.
CommandArgument - Record Class in org.springframework.shell.core.command
Record representing the definition as well as the runtime information about a command argument.
CommandArgument(int, String, String, String, Class<?>) - Constructor for record class org.springframework.shell.core.command.CommandArgument
Creates an instance of a CommandArgument record class.
CommandArgument.Builder - Class in org.springframework.shell.core.command
 
CommandContext - Record Class in org.springframework.shell.core.command
Interface containing runtime information about the current command invocation.
CommandContext(ParsedInput, CommandRegistry, PrintWriter, InputReader) - Constructor for record class org.springframework.shell.core.command.CommandContext
Creates an instance of a CommandContext record class.
CommandCreationException - Exception in org.springframework.shell.core.command
Exception to report that a command in not well-defined.
CommandCreationException(String) - Constructor for exception org.springframework.shell.core.command.CommandCreationException
 
CommandCreationException(String, Throwable) - Constructor for exception org.springframework.shell.core.command.CommandCreationException
 
CommandExecutionException - Exception in org.springframework.shell.core.command
Exception to signal that an error happened while executing a command.
CommandExecutionException(String) - Constructor for exception org.springframework.shell.core.command.CommandExecutionException
Create a new CommandExecutionException with the given message.
CommandExecutionException(String, int) - Constructor for exception org.springframework.shell.core.command.CommandExecutionException
Create a new CommandExecutionException with the given message and exit code.
CommandExecutionException(String, Throwable) - Constructor for exception org.springframework.shell.core.command.CommandExecutionException
Create a new CommandExecutionException with the given message and cause.
CommandExecutor - Class in org.springframework.shell.core.command
Executes commands based on parsed input.
CommandExecutor(CommandRegistry) - Constructor for class org.springframework.shell.core.command.CommandExecutor
Create a new CommandExecutor instance.
CommandFactoryBean - Class in org.springframework.shell.core.command.annotation.support
Factory bean to build instances of Command.
CommandFactoryBean(Method) - Constructor for class org.springframework.shell.core.command.annotation.support.CommandFactoryBean
 
CommandGroup - Annotation Interface in org.springframework.shell.core.command.annotation
Annotation marking a class as a command group.
commandName() - Method in record class org.springframework.shell.core.command.ParsedInput
Returns the value of the commandName record component.
commandName(String) - Method in class org.springframework.shell.core.command.ParsedInput.Builder
 
CommandNotFoundException - Exception in org.springframework.shell.core.command
Exception to signal that a command could be mapped to user input
CommandNotFoundException(String) - Constructor for exception org.springframework.shell.core.command.CommandNotFoundException
 
commandOption(CommandOption) - Method in class org.springframework.shell.core.command.completion.CompletionContext
Return a copy of this context with given command option.
CommandOption - Record Class in org.springframework.shell.core.command
Record representing the definition as well as the runtime information about a command option.
CommandOption(char, String, String, Boolean, String, String, Class<?>) - Constructor for record class org.springframework.shell.core.command.CommandOption
Creates an instance of a CommandOption record class.
CommandOption.Builder - Class in org.springframework.shell.core.command
 
CommandParser - Interface in org.springframework.shell.core.command
Interface for parsing input for a Command.
commandRegistration(Command) - Method in class org.springframework.shell.core.command.completion.CompletionContext
Return a copy of this context with given command registration.
commandRegistry() - Method in record class org.springframework.shell.core.command.CommandContext
Returns the value of the commandRegistry record component.
CommandRegistry - Class in org.springframework.shell.core.command
Class representing a registry of Commands.
CommandRegistry() - Constructor for class org.springframework.shell.core.command.CommandRegistry
 
CommandRegistry(Set<Command>) - Constructor for class org.springframework.shell.core.command.CommandRegistry
 
commitId() - Method in record class org.springframework.shell.core.command.Version.GitProperties
Returns the value of the commitId record component.
commitTime() - Method in record class org.springframework.shell.core.command.Version.GitProperties
Returns the value of the commitTime record component.
complete() - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
complete(boolean) - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
CompletionContext - Class in org.springframework.shell.core.command.completion
Represents the buffer context in which completion was triggered.
CompletionContext(List<String>, int, int, Command, CommandOption) - Constructor for class org.springframework.shell.core.command.completion.CompletionContext
 
CompletionProposal - Class in org.springframework.shell.core.command.completion
Represents a proposal for TAB completion, made not only of the text to append, but also metadata about the proposal.
CompletionProposal(String) - Constructor for class org.springframework.shell.core.command.completion.CompletionProposal
 
completionProvider() - Element in annotation interface org.springframework.shell.core.command.annotation.Command
Define completion provider bean name.
completionProvider(CompletionProvider) - Method in class org.springframework.shell.core.command.Command.Builder
 
CompletionProvider - Interface in org.springframework.shell.core.command.completion
Interface resolving completion proposals.
CompositeCompletionProvider - Class in org.springframework.shell.core.command.completion
A completion provider that composes multiple completion providers.
CompositeCompletionProvider(CompletionProvider...) - Constructor for class org.springframework.shell.core.command.completion.CompositeCompletionProvider
Create a new CompositeCompletionProvider with the given providers.
ConsoleInputProvider - Class in org.springframework.shell.core
Input provider based on the JVM's system Console.
ConsoleInputProvider() - Constructor for class org.springframework.shell.core.ConsoleInputProvider
Create a new ConsoleInputProvider instance.
ConsoleInputProvider(Console) - Constructor for class org.springframework.shell.core.ConsoleInputProvider
Create a new ConsoleInputProvider instance.
ConsoleInputReader - Class in org.springframework.shell.core
Implementation of InputReader that reads input from the system console.
ConsoleInputReader(Console) - Constructor for class org.springframework.shell.core.ConsoleInputReader
Create a new ConsoleInputReader instance.
ConsumerCommandAdapter - Class in org.springframework.shell.core.command.adapter
An adapter to adapt a Consumer as a command.
ConsumerCommandAdapter(String, String, String, String, boolean, Consumer<CommandContext>) - Constructor for class org.springframework.shell.core.command.adapter.ConsumerCommandAdapter
currentWord() - Method in class org.springframework.shell.core.command.completion.CompletionContext
Return the whole word the cursor is in, or null if the cursor is past the last word.
currentWordUpToCursor() - Method in class org.springframework.shell.core.command.completion.CompletionContext
 

D

DefaultCommandParser - Class in org.springframework.shell.core.command
Default implementation of CommandParser.
DefaultCommandParser(CommandRegistry) - Constructor for class org.springframework.shell.core.command.DefaultCommandParser
 
DefaultCompletionProvider - Class in org.springframework.shell.core.command.completion
A default implementation of the CompletionProvider interface that provides completion proposals for enum-type command options and handles prefix generation for command options based on the current input context.
DefaultCompletionProvider() - Constructor for class org.springframework.shell.core.command.completion.DefaultCompletionProvider
 
defaultValidator() - Static method in class org.springframework.shell.core.utils.Utils
Gets a default shared validator.
defaultValidatorFactory() - Static method in class org.springframework.shell.core.utils.Utils
Gets a default shared validation factory.
defaultValue() - Element in annotation interface org.springframework.shell.core.command.annotation.Argument
Define argument's default value.
defaultValue() - Element in annotation interface org.springframework.shell.core.command.annotation.Option
Define option default value.
defaultValue() - Method in record class org.springframework.shell.core.command.CommandArgument
Returns the value of the defaultValue record component.
defaultValue() - Method in record class org.springframework.shell.core.command.CommandOption
Returns the value of the defaultValue record component.
defaultValue(String) - Method in class org.springframework.shell.core.command.CommandArgument.Builder
 
defaultValue(String) - Method in class org.springframework.shell.core.command.CommandOption.Builder
 
description() - Element in annotation interface org.springframework.shell.core.command.annotation.Argument
Return a description of the argument.
description() - Element in annotation interface org.springframework.shell.core.command.annotation.Command
Define a command description.
description() - Element in annotation interface org.springframework.shell.core.command.annotation.CommandGroup
The description of the command group.
description() - Element in annotation interface org.springframework.shell.core.command.annotation.Option
Return a short description of the option.
description() - Method in record class org.springframework.shell.core.command.CommandArgument
Returns the value of the description record component.
description() - Method in record class org.springframework.shell.core.command.CommandOption
Returns the value of the description record component.
description() - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
description() - Method in record class org.springframework.shell.core.command.ExitStatus
Returns the value of the description record component.
description(String) - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
description(String) - Method in class org.springframework.shell.core.command.Command.Builder
 
description(String) - Method in class org.springframework.shell.core.command.CommandArgument.Builder
 
description(String) - Method in class org.springframework.shell.core.command.CommandOption.Builder
 
destroy() - Method in class org.springframework.shell.core.InteractiveShellRunner
 
displayText() - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
displayText(String) - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
doExecute(CommandContext) - Method in class org.springframework.shell.core.command.AbstractCommand
 
doExecute(CommandContext) - Method in class org.springframework.shell.core.command.adapter.ConsumerCommandAdapter
 
doExecute(CommandContext) - Method in class org.springframework.shell.core.command.adapter.FunctionCommandAdapter
 
doExecute(CommandContext) - Method in class org.springframework.shell.core.command.adapter.MethodInvokerCommandAdapter
 
doExecute(CommandContext) - Method in class org.springframework.shell.core.command.Clear
 
doExecute(CommandContext) - Method in class org.springframework.shell.core.command.Help
 
doExecute(CommandContext) - Method in class org.springframework.shell.core.command.Script
 
doExecute(CommandContext) - Method in class org.springframework.shell.core.command.Version
 
dontQuote() - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
dontQuote(boolean) - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
drop(int) - Method in class org.springframework.shell.core.command.completion.CompletionContext
Return a copy of this context, as if the first nbWords were not present

E

EnableCommand - Annotation Interface in org.springframework.shell.core.command.annotation
Enable support for @Command annotated classes.
EnableCommandRegistrar - Class in org.springframework.shell.core.command.annotation.support
ImportBeanDefinitionRegistrar for @EnableCommands.
EnableCommandRegistrar() - Constructor for class org.springframework.shell.core.command.annotation.support.EnableCommandRegistrar
 
EnumCompletionProvider - Class in org.springframework.shell.core.command.completion
A completion provider that knows how to complete values from enumerations.
EnumCompletionProvider(Class<?>) - Constructor for class org.springframework.shell.core.command.completion.EnumCompletionProvider
Create a new EnumCompletionProvider for the given enum type.
EnumCompletionProvider(Class<?>, String) - Constructor for class org.springframework.shell.core.command.completion.EnumCompletionProvider
Create a new EnumCompletionProvider for the given enum type with a prefix.
equals(Object) - Method in class org.springframework.shell.core.command.AbstractCommand
 
equals(Object) - Method in record class org.springframework.shell.core.command.availability.Availability
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class org.springframework.shell.core.command.CommandArgument
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class org.springframework.shell.core.command.CommandContext
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class org.springframework.shell.core.command.CommandOption
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
equals(Object) - Method in record class org.springframework.shell.core.command.ExitStatus
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class org.springframework.shell.core.command.ParsedInput
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class org.springframework.shell.core.command.Version.BuildProperties
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class org.springframework.shell.core.command.Version.GitProperties
Indicates whether some other object is "equal to" this one.
execute(Consumer<CommandContext>) - Method in class org.springframework.shell.core.command.Command.Builder
 
execute(Function<CommandContext, String>) - Method in class org.springframework.shell.core.command.Command.Builder
 
execute(CommandContext) - Method in class org.springframework.shell.core.command.AbstractCommand
 
execute(CommandContext) - Method in interface org.springframework.shell.core.command.Command
Execute the command within the given context.
execute(CommandContext) - Method in class org.springframework.shell.core.command.CommandExecutor
Execute a command based on the given command context.
EXECUTION_ERROR - Static variable in record class org.springframework.shell.core.command.ExitStatus
 
ExitStatus - Record Class in org.springframework.shell.core.command
Record representing the exit status of a command.
ExitStatus(int, String) - Constructor for record class org.springframework.shell.core.command.ExitStatus
Creates an instance of a ExitStatus record class.
exitStatusExceptionMapper() - Element in annotation interface org.springframework.shell.core.command.annotation.Command
Define exit status exception mapper bean name.
exitStatusExceptionMapper(ExitStatusExceptionMapper) - Method in class org.springframework.shell.core.command.Command.Builder
 
ExitStatusExceptionMapper - Interface in org.springframework.shell.core.command.exit
Interface to map exceptions to ExitStatus.

F

FileInputProvider - Class in org.springframework.shell.core
An InputProvider that reads input from a file.
FileInputProvider(File) - Constructor for class org.springframework.shell.core.FileInputProvider
Create a new FileInputProvider instance.
FileNameCompletionProvider - Class in org.springframework.shell.core.command.completion
A CompletionProvider that can populate names of local Files, either absolute or relative to the current working directory.
FileNameCompletionProvider() - Constructor for class org.springframework.shell.core.command.completion.FileNameCompletionProvider
 
flush() - Method in class org.springframework.shell.core.InteractiveShellRunner
Flush the output.
flush() - Method in class org.springframework.shell.core.SystemShellRunner
 
formatAvailableCommands(CommandRegistry) - Static method in class org.springframework.shell.core.utils.Utils
Get a formatted string of available non-hidden commands from the command registry.
FunctionCommandAdapter - Class in org.springframework.shell.core.command.adapter
An adapter to adapt a Function as a command.
FunctionCommandAdapter(String, String, String, String, boolean, Function<CommandContext, String>) - Constructor for class org.springframework.shell.core.command.adapter.FunctionCommandAdapter

G

getAliases() - Method in class org.springframework.shell.core.command.AbstractCommand
 
getAliases() - Method in interface org.springframework.shell.core.command.Command
Get the aliases of the command.
getArgumentByIndex(int) - Method in record class org.springframework.shell.core.command.CommandContext
Retrieve a command argument by its index.
getArguments() - Method in class org.springframework.shell.core.command.AbstractCommand
 
getArguments() - Method in interface org.springframework.shell.core.command.Command
Get the arguments of the command.
getAvailabilityProvider() - Method in class org.springframework.shell.core.command.AbstractCommand
 
getAvailabilityProvider() - Method in interface org.springframework.shell.core.command.Command
Get the availability provider of the command.
getCommand() - Method in class org.springframework.shell.core.command.completion.CompletionContext
 
getCommandByAlias(String) - Method in class org.springframework.shell.core.command.CommandRegistry
 
getCommandByName(String) - Method in class org.springframework.shell.core.command.CommandRegistry
 
getCommandName() - Method in exception org.springframework.shell.core.command.CommandNotFoundException
 
getCommandOption() - Method in class org.springframework.shell.core.command.completion.CompletionContext
 
getCommands() - Method in class org.springframework.shell.core.command.CommandRegistry
 
getCommandsByPrefix(String) - Method in class org.springframework.shell.core.command.CommandRegistry
 
getCompletionProvider() - Method in class org.springframework.shell.core.command.AbstractCommand
 
getCompletionProvider() - Method in interface org.springframework.shell.core.command.Command
Get the completion provider of the command.
getConsole() - Method in class org.springframework.shell.core.ConsoleInputProvider
 
getConstraintViolations() - Method in exception org.springframework.shell.core.ParameterValidationException
 
getDefaultValueForPrimitiveType(Class<?>) - Static method in class org.springframework.shell.core.utils.Utils
 
getDescription() - Method in class org.springframework.shell.core.command.AbstractCommand
 
getDescription() - Method in interface org.springframework.shell.core.command.Command
Get a short description of the command.
getExitCode() - Method in exception org.springframework.shell.core.command.CommandExecutionException
Return the exit code associated with this exception.
getExitStatusExceptionMapper() - Method in class org.springframework.shell.core.command.AbstractCommand
 
getGroup() - Method in class org.springframework.shell.core.command.AbstractCommand
 
getGroup() - Method in interface org.springframework.shell.core.command.Command
Get the group of the command.
getHelp() - Method in class org.springframework.shell.core.command.AbstractCommand
 
getHelp() - Method in class org.springframework.shell.core.command.Clear
 
getHelp() - Method in interface org.springframework.shell.core.command.Command
Get the help text of the command.
getHelp() - Method in class org.springframework.shell.core.command.Help
 
getHelp() - Method in class org.springframework.shell.core.command.Script
 
getHelp() - Method in class org.springframework.shell.core.command.Version
 
getName() - Method in class org.springframework.shell.core.command.AbstractCommand
 
getName() - Method in interface org.springframework.shell.core.command.Command
Get the name of the command.
getObject() - Method in class org.springframework.shell.core.command.annotation.support.CommandFactoryBean
 
getObjectType() - Method in class org.springframework.shell.core.command.annotation.support.CommandFactoryBean
 
getOptionByLongName(String) - Method in record class org.springframework.shell.core.command.CommandContext
Retrieve a command option by its long name.
getOptionByName(String) - Method in record class org.springframework.shell.core.command.CommandContext
Retrieve a command option by its name (long or short).
getOptionByShortName(char) - Method in record class org.springframework.shell.core.command.CommandContext
Retrieve a command option by its short name.
getOptions() - Method in class org.springframework.shell.core.command.AbstractCommand
 
getOptions() - Method in interface org.springframework.shell.core.command.Command
Get the options of the command.
getOptions() - Method in class org.springframework.shell.core.command.Script
 
getPosition() - Method in class org.springframework.shell.core.command.completion.CompletionContext
 
getReader() - Method in class org.springframework.shell.core.InteractiveShellRunner
Get the input reader.
getReader() - Method in class org.springframework.shell.core.SystemShellRunner
 
getWordIndex() - Method in class org.springframework.shell.core.command.completion.CompletionContext
 
getWords() - Method in class org.springframework.shell.core.command.completion.CompletionContext
 
getWriter() - Method in class org.springframework.shell.core.InteractiveShellRunner
Get the writer to the output.
getWriter() - Method in class org.springframework.shell.core.SystemShellRunner
 
GitProperties(String, String, String, Instant) - Constructor for record class org.springframework.shell.core.command.Version.GitProperties
Creates an instance of a GitProperties record class.
group() - Element in annotation interface org.springframework.shell.core.command.annotation.Command
Define a command group.
group() - Method in record class org.springframework.shell.core.command.Version.BuildProperties
Returns the value of the group record component.
group(String) - Method in class org.springframework.shell.core.command.Command.Builder
 

H

hashCode() - Method in class org.springframework.shell.core.command.AbstractCommand
 
hashCode() - Method in record class org.springframework.shell.core.command.availability.Availability
Returns a hash code value for this object.
hashCode() - Method in record class org.springframework.shell.core.command.CommandArgument
Returns a hash code value for this object.
hashCode() - Method in record class org.springframework.shell.core.command.CommandContext
Returns a hash code value for this object.
hashCode() - Method in record class org.springframework.shell.core.command.CommandOption
Returns a hash code value for this object.
hashCode() - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
hashCode() - Method in record class org.springframework.shell.core.command.ExitStatus
Returns a hash code value for this object.
hashCode() - Method in record class org.springframework.shell.core.command.ParsedInput
Returns a hash code value for this object.
hashCode() - Method in record class org.springframework.shell.core.command.Version.BuildProperties
Returns a hash code value for this object.
hashCode() - Method in record class org.springframework.shell.core.command.Version.GitProperties
Returns a hash code value for this object.
help() - Element in annotation interface org.springframework.shell.core.command.annotation.Command
Define a command help message.
help(String) - Method in class org.springframework.shell.core.command.Command.Builder
 
Help - Class in org.springframework.shell.core.command
A command to display help about all available commands.
Help() - Constructor for class org.springframework.shell.core.command.Help
 
hidden() - Element in annotation interface org.springframework.shell.core.command.annotation.Command
Define command to be hidden.
hidden(boolean) - Method in class org.springframework.shell.core.command.Command.Builder
 

I

index() - Element in annotation interface org.springframework.shell.core.command.annotation.Argument
Index of the argument
index() - Method in record class org.springframework.shell.core.command.CommandArgument
Returns the value of the index record component.
index(int) - Method in class org.springframework.shell.core.command.CommandArgument.Builder
 
InputProvider - Interface in org.springframework.shell.core
To be implemented by components able to provide a "line" of user input, whether interactively or by batch.
inputReader() - Method in record class org.springframework.shell.core.command.CommandContext
Returns the value of the inputReader record component.
InputReader - Interface in org.springframework.shell.core
Interface for reading input from the user.
InteractiveShellRunner - Class in org.springframework.shell.core
Base class for interactive shell runners.
InteractiveShellRunner(InputProvider, CommandParser, CommandRegistry) - Constructor for class org.springframework.shell.core.InteractiveShellRunner
Create a new InteractiveShellRunner instance.
isAvailable() - Method in record class org.springframework.shell.core.command.availability.Availability
 
isHelp(CommandOption) - Method in class org.springframework.shell.core.command.AbstractCommand
 
isHidden() - Method in class org.springframework.shell.core.command.AbstractCommand
 
isHidden() - Method in interface org.springframework.shell.core.command.Command
Check if the command is hidden.
isOptionEqual(String) - Method in record class org.springframework.shell.core.command.CommandOption
 
isProfileActive(Method, Environment) - Static method in class org.springframework.shell.core.utils.Utils
Check if a method is annotated with an active Profile in the given environment.

J

JnaRuntimeHints - Class in org.springframework.shell.core
 
JnaRuntimeHints() - Constructor for class org.springframework.shell.core.JnaRuntimeHints
 

L

longName() - Element in annotation interface org.springframework.shell.core.command.annotation.Option
Long name of an option.
longName() - Method in record class org.springframework.shell.core.command.CommandOption
Returns the value of the longName record component.
longName(String) - Method in class org.springframework.shell.core.command.CommandOption.Builder
 

M

MethodInvokerCommandAdapter - Class in org.springframework.shell.core.command.adapter
An adapter to adapt a method as a command.
MethodInvokerCommandAdapter(String, String, String, String, boolean, Method, Object, ConfigurableConversionService, Validator) - Constructor for class org.springframework.shell.core.command.adapter.MethodInvokerCommandAdapter

N

name() - Element in annotation interface org.springframework.shell.core.command.annotation.Command
Define command as an array.
name() - Element in annotation interface org.springframework.shell.core.command.annotation.CommandGroup
The name of the command group.
name() - Method in record class org.springframework.shell.core.command.Version.BuildProperties
Returns the value of the name record component.
name(String) - Method in class org.springframework.shell.core.command.Command.Builder
 
NonInteractiveShellRunner - Class in org.springframework.shell.core
A ShellRunner that executes commands without entering interactive shell mode.
NonInteractiveShellRunner(CommandParser, CommandRegistry) - Constructor for class org.springframework.shell.core.NonInteractiveShellRunner
Create a new NonInteractiveShellRunner instance.
NonInteractiveShellRunner(CommandParser, CommandRegistry, PrintWriter) - Constructor for class org.springframework.shell.core.NonInteractiveShellRunner
Create a new NonInteractiveShellRunner instance.

O

of(Availability) - Static method in interface org.springframework.shell.core.command.availability.AvailabilityProvider
 
OK - Static variable in record class org.springframework.shell.core.command.ExitStatus
 
Option - Annotation Interface in org.springframework.shell.core.command.annotation
Annotation marking a method parameter as an option to a Command.
options() - Method in record class org.springframework.shell.core.command.ParsedInput
Returns the value of the options record component.
options(CommandOption...) - Method in class org.springframework.shell.core.command.Command.Builder
 
org.springframework.shell.core - package org.springframework.shell.core
Contains core classes for Spring Shell, irrespective of the way commands are actually implemented.
org.springframework.shell.core.command - package org.springframework.shell.core.command
 
org.springframework.shell.core.command.adapter - package org.springframework.shell.core.command.adapter
 
org.springframework.shell.core.command.annotation - package org.springframework.shell.core.command.annotation
 
org.springframework.shell.core.command.annotation.support - package org.springframework.shell.core.command.annotation.support
 
org.springframework.shell.core.command.availability - package org.springframework.shell.core.command.availability
 
org.springframework.shell.core.command.completion - package org.springframework.shell.core.command.completion
 
org.springframework.shell.core.command.exit - package org.springframework.shell.core.command.exit
 
org.springframework.shell.core.config - package org.springframework.shell.core.config
 
org.springframework.shell.core.utils - package org.springframework.shell.core.utils
 
outputWriter() - Method in record class org.springframework.shell.core.command.CommandContext
Returns the value of the outputWriter record component.

P

ParameterValidationException - Exception in org.springframework.shell.core
Thrown when one or more parameters fail bean validation constraints.
ParameterValidationException(Set<ConstraintViolation<Object>>) - Constructor for exception org.springframework.shell.core.ParameterValidationException
 
parse(String) - Method in interface org.springframework.shell.core.command.CommandParser
Parse raw input into a ParsedInput.
parse(String) - Method in class org.springframework.shell.core.command.DefaultCommandParser
 
parsedInput() - Method in record class org.springframework.shell.core.command.CommandContext
Returns the value of the parsedInput record component.
ParsedInput - Record Class in org.springframework.shell.core.command
Record representing the result of parsing user input into commands.
ParsedInput(String, List<String>, List<CommandOption>, List<CommandArgument>) - Constructor for record class org.springframework.shell.core.command.ParsedInput
Creates an instance of a ParsedInput record class.
ParsedInput.Builder - Class in org.springframework.shell.core.command
 
prefix() - Element in annotation interface org.springframework.shell.core.command.annotation.CommandGroup
The prefix of the command group.
print(String) - Method in class org.springframework.shell.core.InteractiveShellRunner
Print a message to the output.
print(String) - Method in class org.springframework.shell.core.SystemShellRunner
 
println(String, CommandContext) - Method in class org.springframework.shell.core.command.AbstractCommand
 
provide() - Method in interface org.springframework.shell.core.config.UserConfigPathProvider
Provides a path to a user config location.

Q

QUIT_COMMAND - Static variable in class org.springframework.shell.core.utils.Utils
 

R

readInput() - Method in class org.springframework.shell.core.ConsoleInputProvider
 
readInput() - Method in class org.springframework.shell.core.ConsoleInputReader
 
readInput() - Method in class org.springframework.shell.core.FileInputProvider
 
readInput() - Method in interface org.springframework.shell.core.InputProvider
Return text entered by user to invoke commands.
readInput() - Method in interface org.springframework.shell.core.InputReader
Read a line of input from the user.
readInput(String) - Method in class org.springframework.shell.core.ConsoleInputReader
 
readInput(String) - Method in interface org.springframework.shell.core.InputReader
Read a line of input from the user with a prompt.
readPassword() - Method in class org.springframework.shell.core.ConsoleInputReader
 
readPassword() - Method in interface org.springframework.shell.core.InputReader
Read a password from the user.
readPassword(String) - Method in class org.springframework.shell.core.ConsoleInputReader
 
readPassword(String) - Method in interface org.springframework.shell.core.InputReader
Read a password from the user with a prompt.
reason() - Method in record class org.springframework.shell.core.command.availability.Availability
Returns the value of the reason record component.
registerBeanDefinitions(AnnotationMetadata, BeanDefinitionRegistry) - Method in class org.springframework.shell.core.command.annotation.support.EnableCommandRegistrar
 
registerCommand(Command) - Method in class org.springframework.shell.core.command.CommandRegistry
 
registerHints(RuntimeHints, ClassLoader) - Method in class org.springframework.shell.core.JnaRuntimeHints
 
required() - Element in annotation interface org.springframework.shell.core.command.annotation.Option
Mark option required.
required() - Method in record class org.springframework.shell.core.command.CommandOption
Returns the value of the required record component.
required(Boolean) - Method in class org.springframework.shell.core.command.CommandOption.Builder
 
run(String[]) - Method in class org.springframework.shell.core.InteractiveShellRunner
 
run(String[]) - Method in class org.springframework.shell.core.NonInteractiveShellRunner
 
run(String[]) - Method in interface org.springframework.shell.core.ShellRunner
Execute ShellRunner with given args.

S

Script - Class in org.springframework.shell.core.command
A command that can read and execute other commands from a file.
Script(CommandRegistry) - Constructor for class org.springframework.shell.core.command.Script
 
setAliases(List<String>) - Method in class org.springframework.shell.core.command.AbstractCommand
 
setApplicationContext(ApplicationContext) - Method in class org.springframework.shell.core.command.annotation.support.CommandFactoryBean
 
setApplicationContext(ApplicationContext) - Method in class org.springframework.shell.core.command.CommandRegistry
 
setApplicationContext(ApplicationContext) - Method in class org.springframework.shell.core.command.Version
 
setArguments(List<CommandArgument>) - Method in class org.springframework.shell.core.command.AbstractCommand
 
setAvailabilityProvider(AvailabilityProvider) - Method in class org.springframework.shell.core.command.AbstractCommand
 
setBuildProperties(Version.BuildProperties) - Method in class org.springframework.shell.core.command.Version
 
setCommandParser(CommandParser) - Method in class org.springframework.shell.core.command.Script
Set the command parser to use to parse commands in the script.
setCompletionProvider(CompletionProvider) - Method in class org.springframework.shell.core.command.AbstractCommand
 
setDebugMode(boolean) - Method in class org.springframework.shell.core.InteractiveShellRunner
Set debug mode.
setEnvironment(Environment) - Method in class org.springframework.shell.core.command.annotation.support.EnableCommandRegistrar
 
setExitStatusExceptionMapper(ExitStatusExceptionMapper) - Method in class org.springframework.shell.core.command.AbstractCommand
 
setGitProperties(Version.GitProperties) - Method in class org.springframework.shell.core.command.Version
 
setOptions(List<CommandOption>) - Method in class org.springframework.shell.core.command.AbstractCommand
 
ShellConfigurationException - Exception in org.springframework.shell.core
 
ShellConfigurationException(String, Throwable) - Constructor for exception org.springframework.shell.core.ShellConfigurationException
 
ShellRunner - Interface in org.springframework.shell.core
Interface for shell runners.
shortCommitId() - Method in record class org.springframework.shell.core.command.Version.GitProperties
Returns the value of the shortCommitId record component.
shortName() - Element in annotation interface org.springframework.shell.core.command.annotation.Option
Short name of an option.
shortName() - Method in record class org.springframework.shell.core.command.CommandOption
Returns the value of the shortName record component.
shortName(char) - Method in class org.springframework.shell.core.command.CommandOption.Builder
 
splitCamelCase(String) - Static method in class org.springframework.shell.core.utils.Utils
Split a CamelCase class name into separate words.
stop() - Method in class org.springframework.shell.core.InteractiveShellRunner
Signal the runner to stop and wait briefly for its thread to exit.
subCommands() - Method in record class org.springframework.shell.core.command.ParsedInput
Returns the value of the subCommands record component.
SystemShellRunner - Class in org.springframework.shell.core
Interactive shell runner based on the JVM's system Console.
SystemShellRunner(ConsoleInputProvider, CommandParser, CommandRegistry) - Constructor for class org.springframework.shell.core.SystemShellRunner
Create a new SystemShellRunner instance.

T

time() - Method in record class org.springframework.shell.core.command.Version.BuildProperties
Returns the value of the time record component.
toString() - Method in record class org.springframework.shell.core.command.availability.Availability
Returns a string representation of this record class.
toString() - Method in record class org.springframework.shell.core.command.CommandArgument
Returns a string representation of this record class.
toString() - Method in record class org.springframework.shell.core.command.CommandContext
Returns a string representation of this record class.
toString() - Method in record class org.springframework.shell.core.command.CommandOption
Returns a string representation of this record class.
toString() - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
toString() - Method in record class org.springframework.shell.core.command.ExitStatus
Returns a string representation of this record class.
toString() - Method in record class org.springframework.shell.core.command.ParsedInput
Returns a string representation of this record class.
toString() - Method in record class org.springframework.shell.core.command.Version.BuildProperties
Returns a string representation of this record class.
toString() - Method in record class org.springframework.shell.core.command.Version.GitProperties
Returns a string representation of this record class.
type() - Method in record class org.springframework.shell.core.command.CommandArgument
Returns the value of the type record component.
type() - Method in record class org.springframework.shell.core.command.CommandOption
Returns the value of the type record component.
type(Class<?>) - Method in class org.springframework.shell.core.command.CommandArgument.Builder
 
type(Class<?>) - Method in class org.springframework.shell.core.command.CommandOption.Builder
 

U

unavailable(String) - Static method in record class org.springframework.shell.core.command.availability.Availability
 
unCamelify(CharSequence) - Static method in class org.springframework.shell.core.utils.Utils
Turn CamelCaseText into gnu-style-lowercase.
unregisterCommand(Command) - Method in class org.springframework.shell.core.command.CommandRegistry
 
upToCursor() - Method in class org.springframework.shell.core.command.completion.CompletionContext
 
USAGE_ERROR - Static variable in record class org.springframework.shell.core.command.ExitStatus
 
UserConfigPathProvider - Interface in org.springframework.shell.core.config
Interface providing a Path to a location where user level runtime configuration files are strored.
Utils - Class in org.springframework.shell.core.utils
Some text utilities.
Utils() - Constructor for class org.springframework.shell.core.utils.Utils
 

V

value() - Element in annotation interface org.springframework.shell.core.command.annotation.Command
value() - Element in annotation interface org.springframework.shell.core.command.annotation.EnableCommand
Defines candidate classes for shell commands.
value() - Method in record class org.springframework.shell.core.command.CommandArgument
Returns the value of the value record component.
value() - Method in record class org.springframework.shell.core.command.CommandOption
Returns the value of the value record component.
value() - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
value(String) - Method in class org.springframework.shell.core.command.CommandArgument.Builder
 
value(String) - Method in class org.springframework.shell.core.command.CommandOption.Builder
 
value(String) - Method in class org.springframework.shell.core.command.completion.CompletionProposal
 
version() - Method in record class org.springframework.shell.core.command.Version.BuildProperties
Returns the value of the version record component.
Version - Class in org.springframework.shell.core.command
Command to print the current version of Spring Shell.
Version() - Constructor for class org.springframework.shell.core.command.Version
 
Version.BuildProperties - Record Class in org.springframework.shell.core.command
 
Version.GitProperties - Record Class in org.springframework.shell.core.command
 

W

wakeup() - Method in class org.springframework.shell.core.InteractiveShellRunner
with() - Static method in record class org.springframework.shell.core.command.CommandArgument
 
with() - Static method in record class org.springframework.shell.core.command.CommandOption
 
A B C D E F G H I J L M N O P Q R S T U V W 
All Classes and Interfaces|All Packages|Serialized Form