All Classes and Interfaces
Class
Description
Base class helping to build shell commands.
Annotation marking a method parameter as an argument to a
Command.Annotation marking a method parameter as a target for a collection of arguments to a
Command.Indicates whether a command is currently available or not.
Interface resolving
Availability.ANSI console clear command.
Annotation marking a method to be a shell command.
Builder for creating command.
Record representing a runtime argument to a command.
Interface containing runtime information about the current command invocation.
Exception to report that a command in not well-defined.
Exception to signal that an error happened while executing a command.
Executes commands based on parsed input.
Factory bean to build instances of
Command.Exception to signal that a command could be mapped to user input
Record representing the definition as well as the runtime information about a command
option.
Interface for parsing input for a
Command.Class representing a registry of
Commands.Represents the buffer context in which completion was triggered.
Represents a proposal for TAB completion, made not only of the text to append, but also
metadata about the proposal.
Interface resolving completion proposals.
A completion provider that composes multiple completion providers.
Input provider based on the JVM's system
Console.Implementation of
InputReader that reads input from the system console.An adapter to adapt a
Consumer as a command.Default implementation of
CommandParser.A default implementation of the
CompletionProvider interface that provides
completion proposals for enum-type command options and handles prefix generation for
command options based on the current input context.Enable support for
@Command annotated classes.ImportBeanDefinitionRegistrar for @EnableCommands.A completion provider that knows how to complete values from enumerations.
Record representing the exit status of a command.
Interface to map exceptions to
ExitStatus.An
InputProvider that reads input from a file.A
CompletionProvider that can populate names of local Files, either
absolute or relative to the current working directory.An adapter to adapt a
Function as a command.A command to display help about all available commands.
To be implemented by components able to provide a "line" of user input, whether
interactively or by batch.
Interface for reading input from the user.
Base class for interactive shell runners.
An adapter to adapt a method as a command.
A
ShellRunner that executes commands without entering interactive shell mode.Annotation marking a method parameter as an option to a
Command.Thrown when one or more parameters fail bean validation constraints.
Record representing the result of parsing user input into commands.
A command that can read and execute other commands from a file.
Interface for shell runners.
Interactive shell runner based on the JVM's system
Console.Interface providing a
Path to a location where user level runtime configuration
files are strored.Some text utilities.
Command to print the current version of Spring Shell.